@@ -45,6 +45,8 @@ class HPOConfiguration(ConfigurationBase):
             parser.add_argument('--stop', metavar='',
                                 help='Stopping criteria for the training',
                                 default=kDefaultStopping)
+            parser.add_argument('-r','--resource', metavar='',
+                                help='Resource allocated to each trial')            
             parser.add_argument('--scheduler_param', metavar='',
                                 help='Extra parameters given to the trial scheduler', 
                                 default=kDefaultSchedulerParam)
@@ -58,7 +60,7 @@ class HPOConfiguration(ConfigurationBase):
     def process_config(self, config):
         super().process_config(config)
 
-        json_interp = ['stop', 'scheduler_param', 'algorithm_param']
+        json_interp = ['stop', 'scheduler_param', 'algorithm_param', 'resource']
         for key in json_interp:
             if (key in config) and isinstance(config[key],str):
                 try:
