@@ -99,8 +99,8 @@ def get_physical_devices(device_type='GPU'):
     return physical_devices
 
 def get_n_gpu():
-	import torch
-	return torch.cuda.device_count()	
+    physical_devices = get_physical_devices('GPU')
+    return len(physical_devices)
 
 def get_n_cpu():
     return multiprocessing.cpu_count()
